@@ -2,7 +2,8 @@
 # A launcher program for launching commands, with the ability to
 # open dialogs to ask for input.
 #
-# Released under GPLv2 or later
+# Written by Anton Kindestam <antonki@kth.se>
+# Released under GPLv3 or later
 
 import gtk, hildon
 import sys, os
@@ -58,9 +59,11 @@ def find_idx(f, seq):
 
 def fork_and_do(fn):
     '''Forks calls fn, then calls sys.exit()'''
-    if os.fork() == 0:
+    pid = os.fork()
+    if pid == 0:
         fn()
         sys.exit()
+    return pid
 
 def quote_for_sh(str):
     '''Quotes str with single quotes while handling single quotes
@@ -97,26 +100,40 @@ def text_dialog(password=False):
         raise DialogAbortedException('')
     return text
 
-# def touchselectorentry_dialog():
-#     global window, current_buhtoon, current_specifier_number
+def touchselectorentry_dialog():
+    global window, current_buhtoon, current_specifier_number
 
-#     dialog = gtk.Dialog('', window)
-#     selector = hildon.TouchSelectorEntry(text=True)
+    lst_key = 'touchselectorentry-list' + str(current_specifier_number) or ''
+    
+    dialog = gtk.Dialog('', window)
+    selector = hildon.TouchSelectorEntry(text=True)
+    # selector = hildon.touch_selector_entry_new_text()
 
-#     selector.connect('activate', response_to_dialog, dialog, gtk.RESPONSE_OK)
-#     if current_buhtoon:
-#         for i in current_buhtoon.get('touchselectorentry-list' + current_specifier_number or ''):
-#             selector.append(i)
-#     dialog.vbox.pack_end(selector, True, True, 0)
-#     dialog.show_all()
+    # def f(a,b):
+    #     print a
+    #     print b
+    # selector.connect('changed', f)
+    selector.get_entry().connect('activate', response_to_dialog, dialog, gtk.RESPONSE_OK)
+    if current_buhtoon:
+        if current_buhtoon.get(lst_key):
+            lst = list(current_buhtoon[lst_key])
+            lst.sort()
+            for i in lst:
+                selector.append_text(i)
+        else: # Create the nonexistent field
+            current_buhtoon[lst_key] = set()
+    dialog.vbox.pack_end(selector, True, True, 0)
+    dialog.set_geometry_hints(selector, min_height=300)
+    dialog.show_all()
 
-#     response = dialog.run()
-#     text = selector.get_current_text()
-#     dialog.destroy()
+    response = dialog.run()
+    text = selector.get_current_text()
+    dialog.destroy()
 
-#     if response != gtk.RESPONSE_OK:
-#         raise DialogAbortedException('')
-#     return text
+    if response != gtk.RESPONSE_OK:
+        raise DialogAbortedException('')
+    current_buhtoon[lst_key].add(text) # Add the new one to the set
+    return text
 
 def new_cmd_dialog(edit=None):
     '''edit parameter, if specified, specifies an entry
@@ -215,7 +232,8 @@ def interpolate_string(str):
                 current_specifier_number += 1
                 i < len(str) or raise_BadSpecifierException()
                 result += {'%': lambda: '%',
-                           's': lambda: text_dialog(),
+                           # 's': lambda: text_dialog(),
+                           's': lambda: touchselectorentry_dialog(),
                            'S': lambda: text_dialog(True),
                            'f': lambda: file_dialog(),
                            'F': lambda: file_dialog(True),
